==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/RISKMATRIXSETUPTYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RISKMATRIXSETUPTYPE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RISKMATRIXSETUPTYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RISKMATRIXSETUPTYPECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RISKMATRIXSETUPTYPE_Type", propOrder = {
    "riskmatrixsetuptypecode",
    "description"
})
public class RISKMATRIXSETUPTYPE_Type {

    @XmlElement(name = "RISKMATRIXSETUPTYPECODE", required = true)
    protected String riskmatrixsetuptypecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété riskmatrixsetuptypecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRISKMATRIXSETUPTYPECODE() {
        return riskmatrixsetuptypecode;
    }

    /**
     * Définit la valeur de la propriété riskmatrixsetuptypecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRISKMATRIXSETUPTYPECODE(String value) {
        this.riskmatrixsetuptypecode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RISKMATRIXSETUPTYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RISKMATRIXSETUPTYPE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RISKMATRIXSETUPTYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RISKMATRIXSETUPTYPECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RISKMATRIXSETUPTYPE_Type", propOrder = {
    "riskmatrixsetuptypecode",
    "description"
})
public class RISKMATRIXSETUPTYPE_Type {

    @XmlElement(name = "RISKMATRIXSETUPTYPECODE", required = true)
    protected String riskmatrixsetuptypecode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the riskmatrixsetuptypecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRISKMATRIXSETUPTYPECODE() {
        return riskmatrixsetuptypecode;
    }

    /**
     * Sets the value of the riskmatrixsetuptypecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRISKMATRIXSETUPTYPECODE(String value) {
        this.riskmatrixsetuptypecode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
